@@ -1,9 +1,9 @@
 #!/bin/sh
-export PATH='/usr/obj/ports/hs-async-2.0.2/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
+export PATH='/usr/obj/ports/hs-async-2.1.0/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: async
-version: 2.0.2
-id: async-2.0.2-37ca9def77d6d0a7b0eb0ec80971df94
-key: async_DTdw00O3YMaL0S98EkJDXS
+version: 2.1.0
+id: async-2.1.0-39dbaa8053baa5d86bb55ba090d6bf66
+key: async_5jwpzKVjQQAElehhWvNUXP
 license: BSD3
 copyright: (c) Simon Marlow 2012
 maintainer: Simon Marlow <marlowsd@gmail.com>
@@ -29,58 +29,19 @@ description:
     * The API makes it possible to build a tree of
     threads that are automatically killed when
     their parent dies (see '\''withAsync'\'').
-    .
-    Changes in 2.0.2:
-    .
-    * Add a Monad instance for Concurrently
-    * Bump base dependency to allow 4.9
-    .
-    Changes in 2.0.1.6:
-    .
-    * Add workaround to waitCatch for #14
-    .
-    Changes in 2.0.1.5:
-    .
-    * Bump @base@ dependencies for GHC 7.8
-    .
-    Changes in 2.0.1.4:
-    .
-    * Bump @base@ dependency of test suite
-    .
-    Changes in 2.0.1.3:
-    .
-    * Bump @base@ dependency to allow 4.6
-    .
-    Changes in 2.0.1.2:
-    .
-    * Bump @stm@ dependency to 2.4
-    .
-    Changes in 2.0.1.1:
-    .
-    * Safe Haskell support: @Control.Concurrent.Async@ is now @Trustworthy@
-    .
-    Changes in 2.0.1.0:
-    .
-    * Added a @Functor@ instance for @Async@
-    .
-    * Added @asyncBound@, @asyncOn@, @asyncWithUnmask@, @asyncOnWithUnmask@, @withAsyncBound@, @withAsyncOn@, @withAsyncWithUnmask@, @withAsyncOnWithUnmask@.
-    .
-    * Added @mapConcurrently@
-    .
-    * Added @Concurrently@ (with @Applicative@ and @Alternative@ instances)
 category: Concurrency
 author: Simon Marlow
 exposed: True
 exposed-modules:
     Control.Concurrent.Async
 trusted: False
-import-dirs: /usr/local/lib/ghc/async-2.0.2
-library-dirs: /usr/local/lib/ghc/async-2.0.2
-data-dir: /usr/local/share/hs-async-2.0.2
-hs-libraries: HSasync-2.0.2-DTdw00O3YMaL0S98EkJDXS
+import-dirs: /usr/local/lib/ghc/async-2.1.0
+library-dirs: /usr/local/lib/ghc/async-2.1.0
+data-dir: /usr/local/share/hs-async-2.1.0
+hs-libraries: HSasync-2.1.0-5jwpzKVjQQAElehhWvNUXP
 depends:
     base-4.8.2.0-8dd7859ce039df9f3d3f4ff9dbf4bb93
     stm-2.4.4-e969ad03f1a61caf3d689ab8ef7862f8
-haddock-interfaces: /usr/local/share/doc/hs-async-2.0.2/html/async.haddock
-haddock-html: /usr/local/share/doc/hs-async-2.0.2/html
+haddock-interfaces: /usr/local/share/doc/hs-async-2.1.0/html/async.haddock
+haddock-html: /usr/local/share/doc/hs-async-2.1.0/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
